"""Miscellaneous functions."""


def do_nothing():
    """Do basically nothing."""
    if False:
        print("HEY! I'm doing something!")


class A:
    """A class."""

    def __len__(self):
        """Get length."""
        pass


class B(A):
    """B class."""

    def __len__(self):
        """Get length."""
        return 1



"""Say hello function usage example."""
from helloworld import say_hello

# Generate "Hello world!"
greeting = say_hello()
print(greeting)

# Generate "Hello mkmenta!"
greeting = say_hello("mkmenta")
print(greeting)



import os
import sys
from importlib import import_module

from setuptools import setup

# If we do from helloworld import __version__ etc. we will get an error because requirements for imports in __init__.py
# are not yet installed. This is an ugly way to do it but I haven't found a better way.
sys.path.append(os.path.join(os.path.split(__file__)[0], "helloworld"))
info = import_module("_info")

with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name="helloworld-mkmenta",
    version=info.__version__,
    description="Say hello!",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url=info.__url__,
    author=info.__author__,
    author_email="thisisnotmyemail@gmail.com",
    packages=["helloworld"],
    # You can take classifiers from https://pypi.org/classifiers/
    classifiers=[
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    install_requires=[
        "termcolor >= 1.1.0"  # we don't really need this to be >=1.1.0, is just to give an example
    ],
    extras_require={
        "dev": [
            "pytest",
            "pydocstyle",
            "pycodestyle"
        ]
    }
)



"""The Hello World package."""
from hashlib import blake2b

from termcolor import colored

from ._info import *


def say_hello(name=None):
    """Say hello to the world or someone.

    Args:
        name (str): who you want to greet. If None it will greet the world.

    Returns:
        A string with the greeting.

    """
    if name is None:
        return colored("Hello world!", "blue")

    h = blake2b(digest_size=20)
    h.update(name.encode())
    if h.hexdigest() == 'df543254a1110b5d32d96028cf4b1df9ea96ebbb':
        return "I'm on the radioooooo!!!"

    return colored(f"Hello {name}!", "green")



from helloworld import say_hello


def test_helloworld_no_params():
    assert say_hello() == "\x1b[34mHello world!\x1b[0m"


def test_helloworld_with_param():
    assert say_hello("mkmenta") == "\x1b[32mHello mkmenta!\x1b[0m"
